@@ -1540,7 +1540,7 @@ Socket::Error UDPSocket::join(const IPV4Multicast &ia,int InterfaceIndex)
 	int retval = setsockopt(so, IPPROTO_IP, IP_ADD_MEMBERSHIP, (char *)&group, sizeof(group));
 	return errSuccess;
 
-#elif defined(IP_ADD_MEMBERSHIP) && defined(SIOCGIFINDEX) && !defined(__FreeBSD__) && !defined(_OSF_SOURCE) && !defined(__hpux) && !defined(__GNU__)
+#elif defined(IP_ADD_MEMBERSHIP) && defined(SIOCGIFINDEX) && !defined(__FreeBSD__) && !defined(__FreeBSD_kernel__) && !defined(_OSF_SOURCE) && !defined(__hpux) && !defined(__GNU__)
 
 		struct ip_mreqn      group;
 	struct sockaddr_in   myaddr;
@@ -1580,7 +1580,7 @@ Socket::Error UDPSocket::join(const IPV4Multicast &ia,int InterfaceIndex)
 Socket::Error UDPSocket::getInterfaceIndex(const char *DeviceName,int& InterfaceIndex)
 {
 #ifndef WIN32
-#if defined(IP_ADD_MEMBERSHIP) && defined(SIOCGIFINDEX) && !defined(__FreeBSD__) && !defined(_OSF_SOURCE) && !defined(__hpux) && !defined(__GNU__)
+#if defined(IP_ADD_MEMBERSHIP) && defined(SIOCGIFINDEX) && !defined(__FreeBSD__) && !defined(__FreeBSD_kernel__) && !defined(_OSF_SOURCE) && !defined(__hpux) && !defined(__GNU__)
 
   struct ip_mreqn  mreqn;
   struct ifreq     m_ifreq;
