@@ -4,24 +4,24 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -68,16 +68,14 @@ streambuf(),
 #else
 	istream((streambuf *)this),
 #endif
-	bufsize(0),gbuf(NULL),fp(0)
-{
+	bufsize(0),gbuf(NULL),fp(0) {
 #ifdef	HAVE_OLD_IOSTREAM
 	init((streambuf *)this);
 #endif
 
 	throwflag = tf;
 	fp = ::gzopen(name, "rb");
-	if(!fp)
-	{
+	if(!fp) {
 #ifdef	COMMON_STD_EXCEPTION
 		if(Thread::getException() == Thread::throwException && throwflag)
 			throw IOZException(String(::gzerror(fp, NULL)));
@@ -92,12 +90,11 @@ streambuf(),
 IZStream::IZStream(bool tf) :
 streambuf(),
 #ifdef  HAVE_OLD_IOSTREAM
-        istream(),
+	istream(),
 #else
-        istream((streambuf *)this),
+	istream((streambuf *)this),
 #endif
-        bufsize(0),gbuf(NULL),fp(0)
-{
+	bufsize(0),gbuf(NULL),fp(0) {
 #ifdef	HAVE_OLD_IOSTREAM
 	init((streambuf *)this);
 #endif
@@ -115,8 +112,7 @@ void IZStream::open(const char *name, size_t size)
 		close();
 
 	fp = ::gzopen(name, "rb");
-	if(!fp)
-	{
+	if(!fp) {
 #ifdef	COMMON_STD_EXCEPTION
 		if(Thread::getException() == Thread::throwException && throwflag)
 			throw IOZException(String(::gzerror(fp, NULL)));
@@ -131,7 +127,7 @@ void IZStream::close(void)
 {
 	if(gbuf)
 		delete[] gbuf;
-	
+
 	::gzclose(fp);
 	fp = 0;
 
@@ -142,8 +138,7 @@ void IZStream::close(void)
 
 void IZStream::allocate(size_t size)
 {
-	if(size < 2)
-	{
+	if(size < 2) {
 		bufsize = 1;
 		gbuf = 0;
 		return;
@@ -183,12 +178,12 @@ int IZStream::uflow()
 	int ret = underflow();
 
 	if (ret == EOF)
-		return EOF; 
+		return EOF;
 
 	if (bufsize != 1)
-		gbump(1); 
+		gbump(1);
 
-	return ret; 
+	return ret;
 }
 
 int IZStream::underflow()
@@ -196,11 +191,9 @@ int IZStream::underflow()
 	ssize_t rlen = 1;
 	unsigned char ch;
 
-	if(bufsize == 1)
-	{
+	if(bufsize == 1) {
 		rlen = ::gzread(fp, &ch, 1);
-		if(rlen < 1)
-		{
+		if(rlen < 1) {
 			if(rlen < 0)
 				clear(ios::failbit | rdstate());
 			return EOF;
@@ -216,8 +209,7 @@ int IZStream::underflow()
 
 	rlen = (ssize_t)((gbuf + bufsize) - eback());
 	rlen = ::gzread(fp, eback(), rlen);
-	if(rlen < 1)
-	{
+	if(rlen < 1) {
 		clear(ios::failbit | rdstate());
 		return EOF;
 	}
@@ -235,22 +227,20 @@ streambuf(),
 #else
 	ostream((streambuf *)this),
 #endif
-	bufsize(0),pbuf(NULL),fp(0)
-{
+	bufsize(0),pbuf(NULL),fp(0) {
 	char mode[4];
 
 #ifdef	HAVE_OLD_IOSTREAM
 	init((streambuf *)this);
 #endif
-	
+
 	strcpy(mode, "wb\0");
 	if(level != Z_DEFAULT_COMPRESSION)
 		mode[2] = '0' + level;
-		
+
 	throwflag = tf;
 	fp = ::gzopen(name, mode);
-	if(!fp)
-	{
+	if(!fp) {
 #ifdef	COMMON_STD_EXCEPTION
 		if(Thread::getException() == Thread::throwException && throwflag)
 			throw IOZException(String(::gzerror(fp, NULL)));
@@ -265,12 +255,11 @@ streambuf(),
 OZStream::OZStream(bool tf) :
 streambuf(),
 #ifdef  HAVE_OLD_IOSTREAM
-        ostream(),
+	ostream(),
 #else
-        ostream((streambuf *)this),
+	ostream((streambuf *)this),
 #endif
-        bufsize(0),pbuf(NULL),fp(0)
-{
+	bufsize(0),pbuf(NULL),fp(0) {
 #ifdef	HAVE_OLD_IOSTREAM
 	init((streambuf *)this);
 #endif
@@ -285,17 +274,16 @@ OZStream::~OZStream()
 void OZStream::open(const char *name, int level, size_t size)
 {
 	char mode[4];
-	
+
 	if(fp)
 		close();
-		
+
 	strcpy(mode, "wb\0");
 	if(level != Z_DEFAULT_COMPRESSION)
 		mode[2] = '0' + level;
 
 	fp = ::gzopen(name, mode);
-	if(!fp)
-	{
+	if(!fp) {
 #ifdef	COMMON_STD_EXCEPTION
 		if(Thread::getException() == Thread::throwException && throwflag)
 			throw IOZException(String(::gzerror(fp, NULL)));
@@ -310,7 +298,7 @@ void OZStream::close(void)
 {
 	if(pbuf)
 		delete[] pbuf;
-	
+
 	::gzclose(fp);
 	fp = 0;
 
@@ -321,8 +309,7 @@ void OZStream::close(void)
 
 void OZStream::allocate(size_t size)
 {
-	if(size < 2)
-	{
+	if(size < 2) {
 		bufsize = 1;
 		pbuf = 0;
 		return;
@@ -359,15 +346,13 @@ int OZStream::overflow(int c)
 	unsigned char ch;
 	ssize_t rlen, req;
 
-	if(bufsize == 1)
-	{
+	if(bufsize == 1) {
 		if(c == EOF)
 			return 0;
 
 		ch = (unsigned char)(c);
 		rlen = ::gzwrite(fp, &ch, 1);
-		if(rlen < 1)
-		{
+		if(rlen < 1) {
 			if(rlen < 0)
 				clear(ios::failbit | rdstate());
 			return EOF;
@@ -380,11 +365,9 @@ int OZStream::overflow(int c)
 		return EOF;
 
 	req = (ssize_t)(pptr() - pbase());
-	if(req)
-	{
+	if(req) {
 		rlen = ::gzwrite(fp, pbase(), req);
-		if(rlen < 1)
-		{
+		if(rlen < 1) {
 			if(rlen < 0)
 				clear(ios::failbit | rdstate());
 			return EOF;
@@ -399,8 +382,7 @@ int OZStream::overflow(int c)
 	setp(pbuf, pbuf + bufsize);
 	pbump(req);
 
-	if(c != EOF)
-	{
+	if(c != EOF) {
 		*pptr() = (unsigned char)c;
 		pbump(1);
 	}
